#
# spec file for package budgie-desktop
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2013-2016 Ikey Doherty <ikey@solus-project.com>
# Copyright (c) 2021 Callum Farmer <gmbr3@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} < 1550
%define _distconfdir %{_sysconfdir}
%endif
%if 0%{?suse_version} < 1599
%bcond_with magpie
%else
%bcond_without magpie
%endif
Name:           budgie-desktop
Version:        10.9+2
Release:        1.1
Summary:        GTK3 Desktop Environment
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/GUI/Other
URL:            https://github.com/BuddiesOfBudgie/budgie-desktop
Source0:        %{name}-%{version}.tar.xz
# Solus stupid 1000
BuildRequires:  budgie-screensaver
BuildRequires:  intltool
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  sassc
BuildRequires:  zenity
BuildRequires:  pkgconfig(accountsservice)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(gnome-desktop-3.0)
BuildRequires:  pkgconfig(gnome-settings-daemon) >= 41.0
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(ibus-1.0)
BuildRequires:  pkgconfig(libgnome-menu-3.0)
%if %{with magpie}
BuildRequires:  pkgconfig(libmagpie-0)
%else
BuildRequires:  (pkgconfig(libmutter-11) or pkgconfig(libmutter-10))
%endif
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libpeas-gtk-1.0)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libwnck-3.0)
BuildRequires:  pkgconfig(polkit-agent-1)
BuildRequires:  pkgconfig(polkit-gobject-1)
BuildRequires:  pkgconfig(upower-glib)
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(vapigen)
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(libcanberra)
BuildRequires:  pkgconfig(libcanberra-gtk3)
BuildRequires:  pkgconfig(libxfce4windowing-0)
BuildRequires:  pkgconfig(upower-glib)
# remove old applet
Provides:       budgie-trash-applet = 1.7.0
Obsoletes:      budgie-trash-applet < 1.7.0
# flatpak/snap
Requires:       xdg-desktop-portal-gtk
# https://discuss.getsol.us/d/6970-cant-lock-my-screen/3
Conflicts:      gnome-shell
#
# rebrand and gnome porting
Requires:       budgie-desktop-view >= 1.3+0
Requires:       budgie-screensaver >= 5.1.0+0
Requires:       typelib-1_0-Budgie-1_0 >= %{version}
Requires:       typelib-1_0-BudgieRaven-1_0 >= %{version}
Requires:       budgie-desktop-branding >= 20220627.1
Requires:       budgie-control-center >= 1.3.0+0
Requires:       budgie-session >= 0.9.1
%if %{with magpie}
Requires:       magpie >= 0.9.3+0
%endif
Requires:       budgie-backgrounds >= 2.0+0
#
# unchanged SOVER but new APIs
Requires:       libraven0 >= %{version}
Requires:       libbudgietheme0 >= %{version}
Requires:       libbudgie-plugin0 >= %{version}
Requires:       libbudgie-private0 >= %{version}
Requires:       libbudgie-appindexer0 >= %{version}
Requires:       libbudgie-raven-plugin0 >= %{version}
#
Requires:       upower
Requires:       gstreamer
Requires:       libnotify-tools
Requires:       libcanberra-gtk3-module
Requires:       gnome-settings-daemon
Requires:       ibus
Requires:       libgnomesu
Requires:       xdg-user-dirs-gtk
Requires:       zenity
Requires:       NetworkManager-applet
Requires(post): update-alternatives
Requires(postun):update-alternatives

%description
Budgie Desktop is the flagship desktop for the Solus Operating System.

%package -n typelib-1_0-Budgie-1_0
Summary:        Main Introspection bindings for the Budgie Desktop
Group:          System/Libraries
Requires:       typelib-1_0-PeasGtk-1_0

%description -n typelib-1_0-Budgie-1_0
This package provides GObject Introspection files required for
developing Budgie Applets using interpreted languages, such as Python
GObject Introspection bindings.

%package -n typelib-1_0-BudgieRaven-1_0
Summary:        Raven Introspection bindings for the Budgie Desktop
Group:          System/Libraries

%description -n typelib-1_0-BudgieRaven-1_0
This package provides GObject Introspection files required for
developing Budgie Raven plugins using interpreted languages, such as Python
GObject Introspection bindings.

%package devel
Summary:        Development files for the Budgie Desktop
Group:          Development/Libraries/GNOME
Requires:       libraven0 = %{version}
Requires:       libbudgietheme0 = %{version}
Requires:       libbudgie-plugin0 = %{version}
Requires:       libbudgie-private0 = %{version}
Requires:       libbudgie-appindexer0 = %{version}
Requires:       libbudgie-raven-plugin0 = %{version}

%description devel
This package provides development files required for software to be
able to use and link against the Budgie APIs, to create their own
applets for the Budgie Panel.

%package doc
Summary:        Documentation files for the Budgie Desktop
Group:          Documentation/HTML
Supplements:    (budgie-desktop and patterns-base-documentation)

%description doc
This package provides API Documentation for the Budgie Plugin API, in the
GTK-Doc HTML format.

%package -n libraven0
Summary:        Shared library for Raven
Group:          System/Libraries

%description -n libraven0
Budgie Desktop Notification Center.

%package -n libbudgietheme0
Summary:        Shared library for Budgie theming
Group:          System/Libraries

%description -n libbudgietheme0
Budgie theming engine shared library package.

%package -n libbudgie-plugin0
Summary:        Shared library for Budgie plugins
Group:          System/Libraries

%description -n libbudgie-plugin0
Shared library for budgie plugins to link against.

%package -n libbudgie-private0
Summary:        Private library for Budgie
Group:          System/Libraries

%description -n libbudgie-private0
Private library for Budgie desktop to link against.

%package -n libbudgie-appindexer0
Summary:        Private library for Budgie Menu
Group:          System/Libraries

%description -n libbudgie-appindexer0
Private library for Budgie menu to link against.

%package -n libbudgie-raven-plugin0
Summary:        Shared library for Budgie raven plugins
Group:          System/Libraries

%description -n libbudgie-raven-plugin0
Shared library for budgie raven plugins to link against.

%lang_package

%prep
%autosetup

%build
export CFLAGS="%{optflags} -Wno-pedantic"
%meson -Dc_std=none -Dxdg-appdir=%{_distconfdir}/xdg/autostart
%meson_build

%install
%meson_install

# update-alternatives
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/default-xsession.desktop
ln -s %{_sysconfdir}/alternatives/default-xsession.desktop %{buildroot}%{_datadir}/xsessions/default.desktop

# handled by budgie-screensaver
rm %{buildroot}%{_distconfdir}/xdg/autostart/org.buddiesofbudgie.BudgieDesktopScreensaver.desktop

%find_lang %{name}

%post
%{_sbindir}/update-alternatives --install %{_datadir}/xsessions/default.desktop \
  default-xsession.desktop %{_datadir}/xsessions/budgie-desktop.desktop 20

%postun
[ -f %{_datadir}/xsessions/budgie-desktop.desktop ] || %{_sbindir}/update-alternatives \
  --remove default-xsession.desktop %{_datadir}/xsessions/budgie-desktop.desktop

%ldconfig_scriptlets -n libraven0
%ldconfig_scriptlets -n libbudgietheme0
%ldconfig_scriptlets -n libbudgie-plugin0
%ldconfig_scriptlets -n libbudgie-private0
%ldconfig_scriptlets -n libbudgie-appindexer0
%ldconfig_scriptlets -n libbudgie-raven-plugin0

%files
%license LICENSE LICENSE.LGPL2.1
%{_bindir}/budgie-*
%{_bindir}/org.buddiesofbudgie*
%{_libexecdir}/budgie-desktop
%{_mandir}/man1/*%{?ext_man}
%{_datadir}/budgie
%{_datadir}/applications/*.desktop
%{_datadir}/backgrounds
%{_datadir}/glib-2.0/schemas/*.gschema.xml
%{_datadir}/glib-2.0/schemas/*.gschema.override
%{_datadir}/icons/hicolor/scalable/*/*.svg
%{_datadir}/gnome-session
%{_datadir}/xsessions/default.desktop
%{_datadir}/xsessions/budgie-desktop.desktop
%dir %{_datadir}/xdg-desktop-portal
%{_datadir}/xdg-desktop-portal/budgie-portals.conf
%{_libdir}/budgie-desktop
%{_distconfdir}/xdg/autostart/*.desktop
%ghost %{_sysconfdir}/alternatives/default-xsession.desktop
%ghost %{_sysconfdir}/alternatives/default.desktop

%files -n libraven0
%{_libdir}/libraven.so.*

%files -n libbudgietheme0
%{_libdir}/libbudgietheme.so.*

%files -n libbudgie-plugin0
%dir %{_libdir}/budgie-desktop
%dir %{_libdir}/budgie-desktop/plugins
%{_libdir}/libbudgie-plugin.so.*

%files -n libbudgie-private0
%{_libdir}/libbudgie-private.so.*

%files -n libbudgie-appindexer0
%{_libdir}/libbudgie-appindexer.so.*

%files -n libbudgie-raven-plugin0
%{_libdir}/libbudgie-raven-plugin.so.*

%files devel
%{_includedir}/budgie-desktop
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so
%{_datadir}/gir-1.0/Budgie-1.0.gir
%{_datadir}/gir-1.0/BudgieRaven-1.0.gir
%{_datadir}/vala/vapi/budgie-1.0.*
%{_datadir}/vala/vapi/budgie-raven-plugin-1.0.*

%files -n typelib-1_0-Budgie-1_0
%{_libdir}/girepository-1.0/Budgie-1.0.typelib

%files -n typelib-1_0-BudgieRaven-1_0
%{_libdir}/girepository-1.0/BudgieRaven-1.0.typelib

%files doc
%{_datadir}/gtk-doc/html/budgie-desktop

%files lang -f %{name}.lang

%changelog
* Thu Feb  1 2024 gmbr3@opensuse.org
- Update to version 10.9+2:
  * fix: multiple tabswitcher bugs
  * sendto: Use stateless XDG autostart directory if stateless is
    set
* Mon Jan 29 2024 gmbr3@opensuse.org
- Update to version 10.9+0:
  * Release 10.9
  * Update translations
  * Implement a new Bluetooth indicator
    (goodbye GNOME Bluetooth v1 :) )
  * Start requiring budgie-session
  * Port TabSwitcher & Workspace applets over to libxfce4windowing
- Move autostart back to %%_distconfdir as aaa_base is fixed
- Add more specific dependencies for required userspace tools
* Fri Nov 24 2023 gmbr3@opensuse.org
- Update to version 10.8.2+0:
  * Use user-space variables to pass temporary screenshot data
  * notifications: Try to guess app id if getting from hints fails
  * Fix oversight in custom icon theme path reading
  * Fix initial tray icon scaling
  * Simplify Raven notification group
  * Update translations
  * fix compilation errors against latest gcc
  * Unbox primitives for DBusMenu nodes
  * Add setting for tray icon scaling
  * Make dark theme switch apply to color scheme pref
  * Include keywords when performing fuzzy searches
  * Add xdg-desktop-portal config
  * Work around more SN/dbusmenu quirks
  * Move below initialization of radio buttons
  * Update README for 10.8 assets
- Trash applet not needed for 10.8
* Tue Aug 29 2023 gmbr3@opensuse.org
- Update to version 10.8+0:
  * Drop libmutter-12 support in favor of magpie-0
  * Polkit dialog will now show the action description
    and action ID when graphical privilege escalation is requested
  * Status applet now provides the ability to control the
    Performance / Power profile modes offered by
    power-profiles-daemon.
  * System Tray has adopted the Status Notifier specification
  * Application Indexer's fuzzy scoring function has been
    ported to C
  * Default colour is now green
  * Kvantum and Murrine themes are now hidden in
    Budgie Desktop Settings
  * We now search for plugins in both /usr and /usr/local
* Tue May 16 2023 gmbr3@opensuse.org
- Update to version 10.7.2+0:
  * Just have a use-old-zenity option to avoid issues with
    zenity version detection
  * Bump to 10.7.2
  * Remove comment related to GTK_CHECK_VERSION that causes
    faux error noise during compile
  * fix: check of zenity on OSes with older Meson
  * add detection of zenity version and use different flags for
    old vs new zenity
  * budgie-menu: Make category buttons keyboard navigable
  * Fix screenshot for libmutter-12
  * budgie-menu: Change the selection policy from NONE to SINGLE
  * Fix panel growing memory consumption over increasing numbers
    of notifications
  * Use correct C header for meta_keybindings_set_custom_handler
  * Added code to manage max_notifications_per_group
  * Minor optimizations, edited comments
  * Limited the number of notifications to prevent infinit
    accumulation, causing raven to choke
  * feat: ensure Budgie Menu application lists height
    allocation accounts for GTK scaling factor
  * Fix Gtk gdk_x11_window_get_frame_extents
  - change since Gtk version 3…
  * Fix SoundOutput and Calendar widget settings schemas
  * Relevancy algorithm refinements
* Wed Mar 29 2023 gmbr3@opensuse.org
- Update to version 10.7.1+20:
  * Fix screenshot for libmutter-12
  * Update tray plugin description
  * Add timeout to watcher init in tray applet
  * budgie-menu: Change the selection policy from NONE to SINGLE
  * Fix panel growing memory consumption over increasing numbers
    of notifications
  * Use correct C header for meta_keybindings_set_custom_handler
  * Added code to manage max_notifications_per_group
  * Introduce mutter-12 support (bsc#1209895)
* Sun Feb  5 2023 gmbr3@opensuse.org
- Budgie Desktop 10.7 "Superhero Raven"
  * New application indexer, replacing our use of libgnome-menus
    and unifying our logic used in both Budgie Menu and Budgie Run
    Dialog
  * Budgie Desktop Settings now has a new design for widget
    selection
  * Budgie Menu now leverages switcheroo-control if available to
    switch between GPU environments when launching applications
    that request it
  * Budgie Menu now provides a "personal user menu" which has
    quick XDG directory access
  * In the new bottom strip of Budgie Menu, we now have buttons for
    launching Budgie Desktop Settings, Budgie Control Center
    and our new Power Dialog
  * New Budgie Screenshot application built into the desktop
  * Full list available at:
    https://blog.buddiesofbudgie.org/budgie-10-7-released/
- Add BRs pkgconfig(gee-0.8), pkgconfig(gstreamer-1.0),
  pkgconfig(libcanberra), pkgconfig(libcanberra-gtk3)
- New libraries libbudgie-appindexer0, libbudgie-raven-plugin0
- New introspection binding BudgieRaven-1.0
- Some change of namespace from org.solus-project to
  org.buddiesofbudgie
* Fri Sep  2 2022 gmbr3@opensuse.org
- Update to version 10.6.4+0:
  * Bump to 10.6.4
  * Add missing gio-unix-2.0 dependencies
  * Update timezone if no custom timezone set
  * Resolve numerous issues with the Workspace Applet
* Mon Aug 29 2022 gmbr3@opensuse.org
- Update to version 10.6.3+0:
  * Bump to 10.6.3
  * Add setting for workspace item size
  * Obtain custom timezone using the schema key name
  * Builtin theme: Dim labels in menu when submenus are revealed
  * Add support for Mutter 11 (GNOME 43)
  * Improve scaling change message to request further user action
- Move autostart back to /etc until aaa_base is fixed
* Mon Aug 29 2022 Callum Farmer <gmbr3@opensuse.org>
- Add Recommends xdg-desktop-portal-gnome for flatpak and snapd
  users
* Thu Jul 14 2022 gmbr3@opensuse.org
- Update to version 10.6.2+0:
  * Bump to 10.6.2
  * Reset ITL buttons if group updated while pinned
  * Disconnect from the allocation changed signal to avoid having
    notification popups move unexpectedly
  * Fix math for calculating right panel strut
  * fix broken C std for gvc subproject
  * Set notif popup position after size allocation
  * Rewrite initial applet layout to prevent position desync
  * ITL: Prevent segfault when attempting to swap buttons
  * Workspace item size now independent of workspace width
  * Attempt re-adding nameless windows on name change.
  * Set a mininum expiry timeout for notification popups
  * Drop unnecessary Comment in daemon desktop that produces
    warning.
  * Fixes spec compliance for closing notifications
  * Reset ITL button's first_app and class group app on swap
  * IconTasklist: Swap button key in hashtable when first_app
    changes
  * Fix various compile-time warnings in Vala code
  * Workspaces: Adjust app spacing and align with panel edges
  * Increase size and density of workspaces in workspace applet
  * Use a Mutex for Raven threading
  * Remove gtk3 from lib_applet_budgiemenu_resources deps
  * Compile some gresources into intermediate static libraries
  * Use meson warning_level instead of global warning flags
  * Fix deprecations in vapi and ClockApplet
  * Use simple selectors in _widgets.scss to resolve warning
  * Mark [GtkChild] properties as unowned to resolve compiler
    warnings
  * Regenerate vapi for mutter 10 This commit updates the vapi for
    mutter 10/clutter et al since the stable release of GNOME 42.
    This also fixes an existing issue with our generation of
    CursorTracker.get_pointer where params both return values.
* Wed Jun 22 2022 Callum Farmer <gmbr3@opensuse.org>
- Enforce update to latest budgie-desktop-branding 20220627.1
* Fri May 27 2022 gmbr3@opensuse.org
- Update to version 10.6.1+0:
  * Tag 10.6.1 Release
  * Update button ID to launcher when pinning and open app and
    back to app ID when unpinning it
  * Fix regression where non pinned icons were not reorderable in
    icon tasklist
  * Attempt to fix a regression in dragging that was caused by
    inconsistent application IDs.
  * Remove delay when opening apps
  * Sync translations. Updated transifex config.
  * Remove check for window  hints when removing button in
    Icon tasklist
  * Improve racyness when a notification is closed and another
    one shown in quick succession
  * Fix regression in IconTasklist.
  * Don't modify notification group HashTables while iterating
    over them
  * Re-connect to the Raven signal to clear all notifications
  * Ensure new applications icons are displayed in tasklist
    when using restrict-to-workspace
  * Fix inconsistency when opening Raven
  * Add a null check to budgie_popover_manager_ungrab
* Wed Apr  6 2022 Callum Farmer <gmbr3@opensuse.org>
- Change gnome-bluetooth requires to be compatible with older
  distributions
* Wed Mar 16 2022 Callum Farmer <gmbr3@opensuse.org>
- Fix upgrading from older Budgie by adding versioned Requires on
  shared libraries
- Update versioned Requires for other Budgie applications
* Wed Mar 16 2022 gmbr3@opensuse.org
- Update to version 10.6+4:
  * Only set valid target_icon_size values in icon tasklist
* Wed Mar 16 2022 Callum Farmer <gmbr3@opensuse.org>
- Avoid ISO C warnings by setting -Wno-pedantic and removing
  - std=c11
* Sat Mar 12 2022 gmbr3@opensuse.org
- Update to version 10.6+3:
  * Proper icon tasklist scaling
  * Fix inconsistency when opening Raven
  * Add a null check to budgie_popover_manager_ungrab
* Tue Mar  8 2022 gmbr3@opensuse.org
- Update to version 10.6+0:
  * Tag 10.6 release
  * Fix SEGV when input source was switched by Alt+Shift_L
  * Update tab switcher style for built-in theme
  * Fix panel placement in dock mode
  * Match Raven and Menu buttons to other hover/active colors
  * Remove inset shadow on hover for icon tasklist
  * Remove notification group padding to stop Raven size shifting
  * Add support for mutter 10 / GNOME42
  * Actually fix notification pausing sometimes breaking Firefox
    notifications
  * Fix notification mute button sometimes starting without an image
  * Scale down the logo too
  * Update logo
  * Fix some applications showing their own notification popups when
    paused
  * Fix Current Internal Theme
  * Ensure gschema override for switch-input-source* is formatted
    correctly.
  * Add keywords to budgie-desktop-settings.desktop
  * Perform additional sanity check on add_app due to invalid windows
    being tracked on app closures.
  * Fix vertical panel struts
  * Fix Raven size adjustments.
  * Remove background on notifs in Raven
  * Fix appmenu style with Plata Lumine (and other light themes)
  - CHANGELOG cut here (too long)
- Remove override-syntax.patch: upstreamed
* Fri Jan  7 2022 gmbr3@opensuse.org
- Update to version 10.5.3+36:
  * Require GNOME Stack 40 or later
  * Revert "Require GNOME Stack 41 (alpha+)"
  * Exclude Adwaita and HighContrast from Icon themes selection.
    Neither support Budgie.
  * Prevent crash when deleting twice the same applet
  * Add /usr/bin binary man-pages.
  * Add gnome-screensaver as a possible compilation option.
  * Update copyright year to 2022
  * Rename budgie-desktop-view schema.
    Requires git build of new budgie desktop view
  * Add Matrix badge to README
  * meson: Drop spurious 3rd positional argument to
    gnome.compile_resources
* Fri Nov 26 2021 Callum Farmer <gmbr3@opensuse.org>
- Conflict gnome-shell it's existence breaks locking
* Sat Nov 20 2021 Callum Farmer <gmbr3@opensuse.org>
- Specify gnome-settings-daemon required version
* Fri Nov 12 2021 Callum Farmer <gmbr3@opensuse.org>
- Require xdg-user-dirs-gtk to fix Desktop issues
* Sat Nov  6 2021 Callum Farmer <gmbr3@opensuse.org>
- Move some recommends to patterns-budgie
- Require libgnomesu and nm-applet
* Sat Oct 16 2021 Callum Farmer <gmbr3@opensuse.org>
- clean spec file
* Fri Sep 24 2021 gmbr3@opensuse.org
- Update to version 10.5.3+12:
  * Clock applet: Don't show empty second/date label if not enabled
  * Revert "Use ibus daemonize to allow ibus popups to appear
  * Require GNOME Stack 41 (alpha+)
  * Add Mutter 9 support
  * Update README with intentions going into B11.
  * Use ibus daemonize to allow ibus popups to appear
  * Enable Mod3 (Meta or Hyper) for Tab Switching
* Sun Aug  8 2021 gmbr3@opensuse.org
- Update to version 10.5.3+5:
  * Customizable Clock Applet
  * fix: fixed inconsistent behavior of pinned apps depending
    on how they were pinned (from popover or from drag and drop)
  * fixed issue with user defined keybinding being override
    when keybinding is defined in budgie gschema
  * Update badge to point to Open Collective
  * Update to Libera
- Add override-syntax.patch: fix parsing issues
* Wed Apr 28 2021 gmbr3@opensuse.org
- Update to version 10.5.3+0:
  * Drop version check now that 4.0 is out. Nobody is going
    to be packaging the old releases
  * Update wallpaper to one licensed under CC-BY-SA-3.0
    Bump to 10.5.3
  * Increase likelihood that budgie-desktop is being
    shipped with required component
  * Ship a default wallpaper from Solus
  * Override settings only for Budgie
  * Rewrite fullscreen tracking
  * Sync submodules
  * Change to budgie-screensaver
  * Hide "Default", which is typically Adwaita /
    GTK's internal theme
  * Further updates to README
  * Remove old target date bits from readme
- Removed desktop-override.patch: merged
* Thu Apr 15 2021 gmbr3@opensuse.org
- Update to version 10.5.2+7a5dcfda:
  * Use IconSize.DIALOG instead of IconSize.INVALID,
    only scale if icon isn't already 48px in height.
  * Drop use of Queue and Cancellable.
  * Filter out audacious notifications so they don't
    clutter up Raven.
  * Fix application icons not scaling in Notification
    Group headers.
  * Don't filter device added / removed notifications.
  * Revert "Changed budgie-screensaver dbus name"
- Let budgie-screensaver handle XDG autostart
* Mon Apr 12 2021 gmbr3@opensuse.org
- Update to version 10.5.2+08c9d7cf:
  * Changed budgie-screensaver dbus name
  * Support moved font anti-aliasing and hinting in GSD 40
- Remove budgie-screensaver.patch: merged
* Sun Apr 11 2021 gmbr3@opensuse.org
- Update to version 10.5.2+ff840563:
  * Set an X error handler to catch BadWindow errors
  * Improve stability of CarbonTray
  * Fix issue with VirtualBox icon not being displayed in TaskList
  * enable click on panel icons to toggle lock keys
  * Compile with mutter-8 (GNOME 40 beta)
  * Resolve issues with fullscreen tracking
- Remove GNOME-40.patch: merged
- Remove fullscreen-tracking.patch: merged
- Add budgie-screensaver.patch: to fix conflict with GNOME 40
* Tue Feb 23 2021 Callum Farmer <gmbr3@opensuse.org>
- Update GNOME-40.patch: Fix vapigen warnings for 6,7 & 8 alpha
* Wed Feb 17 2021 Callum Farmer <gmbr3@opensuse.org>
- Add fullscreen-tracking.patch: fix tracking issues
- Add GNOME-40.patch: support for GNOME 40
- Tweaked dependencies on typelibs
- Updated BuildRequires:
  * pkgconfig(libmutter-6/7) >> pkgconfig(libmutter-6/7/8)
* Thu Feb 11 2021 gmbr3@opensuse.org
- Update to version 10.5.2+481e9bd2:
  * Update submodules
  * Resolve issues with status applet spacing persistence
* Mon Jan 11 2021 gmbr3@opensuse.org
- Update to version 10.5.2+e04e3b8f:
  * Add spacing setting to StatusApplet
  * Add setting to pause notifications while apps are fullscreen
  * Synchronize X errors in carbon_child_realize
* Tue Jan  5 2021 gmbr3@opensuse.org
- Update to version 10.5.2+09d4afe9:
  * Update copyright to 2021
  * Prevent Budgie Desktop Settings from being pinned via
    drag-and-drop
  * Use standard mute/unmute methods
* Mon Dec 21 2020 Callum Farmer <gmbr3@opensuse.org>
- Update to version 10.5.2+3d2b8998:
  * Fix regression in Budgie Desktop Settings icon handling
* Wed Dec  9 2020 Callum Farmer <gmbr3@opensuse.org>
- Removed budgie-desktop-nemo-autostart.desktop
- Removed nemo-instead-of-nautilus.patch: nemo no longer used
- Update to version 10.5.2+5a56d6dd:
  * Fix issue with KeePass causing panel segfaults
  * Bump to 10.5.2
  * Last sync of translations before release.
  * Ensure our requirement bumps for GNOME 3.36 stack is consistent.
  * Fix accidental whitespace adding before a namespace.
  * Add Click Policy to Budgie Desktop Settings.
  * Add note that Caja won't be an available override at this time.
  * Sync translations.
  * Rejig nemo support with desktop settings
  * Apply dock mode class on init
* Mon Nov 23 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 10.5.1+ed8be169:
  * Precise fullscreen tracking in Abomination
  * Update carbontray and fix its copyright headers
  * Implement setting to choose which side of the screen Raven
    opens on
* Mon Nov  2 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 10.5.1+21060898:
  * Consolidate WindowType checking code into Abomination.
- Cleaned nemo-instead-of-nautilus.patch
* Fri Oct 23 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 10.5.1+9197f3f0:
  * Support to set XDG directory
  * Fix build with vala 0.49
  * Changes and fixes in Budgie Menu
  * Update translations
- Removed vala-0.49.patch: contained in upstream
- Removed Revert-GNOME-3.38-support.patch: end of Leap 15.2 support
- Rebased nemo-instead-of-nautilus.patch
- Updated BuildRequires:
  * pkgconfig(libmutter-5/6/7) >> pkgconfig(libmutter-6/7)
- Follow UsrEtc move for autostart desktop files
* Sat Sep 19 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Use a better format for testing gnome versions
* Sun Sep 13 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add budgie-desktop-branding to Recommends
* Sat Sep 12 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add patch Revert-GNOME-3.38-support.patch: Leap 15.2 only
- Updated BuildRequires:
  * pkgconfig(libmutter-6/7) >> pkgconfig(libmutter-5/6/7)
* Thu Sep 10 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Revert vala path changes
* Thu Sep 10 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add patch vala-0.49.patch: fixes build with vala 0.49
  (gh#solus-project/budgie-desktop#2029)
* Wed Sep  9 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to git version 10.5.1+1ed6276b:
  * Prevents keeping a load of patches, 10.5.2 might be ages away
  * Added support for GNOME 3.38
  * Removed support for GNOME 3.34 and below
- Removed patches:
  * support-libmutter6.patch
  * Rework-grab-and-ungrab-keys.patch
  * mutter-3-35-91.patch
  * gnome-coexistance.patch
  * replace-na-tray-with-carbontray.patch
  * clean-up-carbontray.patch
  * fix-integration-issues-with-carbontray.patch
- Updated BuildRequires:
  * pkgconfig(libmutter-5/6) >> pkgconfig(libmutter-6/7)
* Sat Sep  5 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add patches to fix boo#1176016:
  * replace-na-tray-with-carbontray.patch
    (gh#solus-project/budgie-desktop#1998)
  * clean-up-carbontray.patch
    (gh#solus-project/budgie-desktop#2002)
  * fix-integration-issues-with-carbontray.patch
    (gh#solus-project/budgie-desktop#2009)
* Mon Aug 31 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add nemo-instead-of-nautilus.patch: Nautilus doesn't have support
  for desktop icons anymore
- Add nemo to Requires for desktop icons
* Sat Aug 29 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add desktop-override.patch from Debian: fixes overlap between
  Budgie and GNOME in gschema
* Sat Aug 29 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add budgie-screensaver to Requires
- Change gnome-software from Requires to Recommends:
  * Asked for by S. B. <sb56637@gmail.com>
* Thu Aug 13 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Change gnome-control-center from Recommends to Requires:
  * Needed for changing desktop background
- Add gnome-software to Requires:
  * Needed for links in gnome-control-center
* Wed Aug 12 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add gnome-session-core as a dependency
- Spec file cleanups
- Correct URL
* Tue Aug 11 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Remove gnome-session dependency
* Mon Aug 10 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fix desktop icons
* Mon Aug 10 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add patches:
  * Rework-grab-and-ungrab-keys.patch
    (gh#solus-project/budgie-desktop#1907)
  * mutter-3-35-91.patch (gh#solus-project/budgie-desktop#1939)
  * gnome-coexistance.patch (gh#solus-project/budgie-desktop#1984)
- Remove old %%post and %%postun
- Add new Requires:
  * ibus
  * typelib-1_0-PeasGtk-1_0
  * typelib-1_0-Budgie-1_0
* Mon Aug 10 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Add xsession update-alternatives
* Sun Aug  9 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Rename and recommend doc package
* Sun Aug  9 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Create separate lang package
* Sat Aug  8 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Move vala to correct directory
- Correct typelib library name
- Removed fix-meson-build.patch: contained in upstream
- Removed support-libmutter2.patch: contained in upstream
- Added support-libmutter6.patch: adds support for mutter 3.36
- Correct license name
- Switch to verified sources:
  * Add source.asc and GPG keyring
- Add new BuildRequires:
  * pkgconfig(libnotify)
  * pkgconfig(gnome-settings-daemon)
  * pkgconfig(alsa)
- Updated BuildRequires:
  * pkgconfig(libmutter-2) >> pkgconfig(libmutter-6)
- Add new library libbudgie-private0
- Update to version 10.5.1:
  * For the changes see
    https://getsol.us/2019/10/03/budgie-and-its-army-of-gnomes/
* Sun Apr 15 2018 matthias.eliasson@gmail.com
- Add support-libmutter2.patch: This to support the version of
  mutter in openSUSE:Factory.
- Change copyright year to 2018
- Change licenses to SPDX-3.0 version
- Modernize spec-file with spec-cleaner
* Thu Nov 30 2017 qantas94heavy@gmail.com
- Add fix-meson-build.patch: fixes gvc subproject sandbox issue
  with Meson 0.43.0
* Mon Sep 18 2017 mailaender@opensuse.org
- Update pkgconfig libmutter-0 to libmutter-1
* Sun Aug 20 2017 mailaender@opensuse.org
- Drop sed fix bdugie-desktop typo (resolved upstream)
* Tue Aug 15 2017 mailaender@opensuse.org
- Update to version 10.4 "Irish Summer"
- Drop upstream gtk-3.22.14+raven-crash-fix.patch
- Drop upstream meson-0.41.patch
- Drop upstream 0001-wm-Default-to-an-empty-rpath.patch
* Mon Jul 24 2017 matcherapy@gmail.com
- fix empty rpath 0001-wm-Default-to-an-empty-rpath.patch
* Sat Jul 22 2017 mailaender@opensuse.org
- Fix build with meson 0.41 using meson-0.41.patch
* Tue Jun 13 2017 jengelh@inai.de
- Redo descriptions.
* Sun Jun  4 2017 mailaender@opensuse.org
- Add gtk-3.22.14+raven-crash-fix.patch to fix #918
* Fri Apr 21 2017 dev+novell@devmotion.de
- Update to v10.3.1
- See https://github.com/budgie-desktop/budgie-desktop/releases/tag/v10.3.1
* Fri Jan 27 2017 mailaender@opensuse.org
- Add https://en.opensuse.org/SourceUrls
- Fix standard-dir-owned-by-package rpmlint warnings
- Implement shared library policy
* Fri Dec 16 2016 ikey.doherty@gmail.com
- Update to v10.2.9 - a maintenance release
- See: https://github.com/budgie-desktop/budgie-desktop/releases/tag/v10.2.9
* Wed Nov  9 2016 sfalken@opensuse.org
- Fixed /usr/bin ownership conflict for F24
* Sat Nov  5 2016 sfalken@opensuse.org
- Added docbook2X buildrequire for Fedora, builds for F24 now
* Sat Nov  5 2016 sfalken@opensuse.org
- Added conditional BuildDeps for Fedora
* Sat Nov  5 2016 sfalken@opensuse.org
- Did some spec cleanup, for maintainability and clarity
* Sat Oct 29 2016 ikey.doherty@gmail.com
- Yet another Fedora change. Strongly considering dropping support for them.
* Sat Oct 29 2016 ikey.doherty@gmail.com
- Explicitly require gtk-doc for Fedora.
* Sat Oct 29 2016 ikey.doherty@gmail.com
- Fix even more build failures with ancient Vala. Circa 1940.
* Sat Oct 29 2016 ikey.doherty@gmail.com
- Reflow patch series specifically to this OBS repo
- Fix build failures on Fedora 22, 23, and openSUSE Leap 42.1 by
  allowing old ibus versions and removing use of Source.REMOVE which
  is unavailable in their vala versions.
* Sat Oct 29 2016 ikey.doherty@gmail.com
- Update to Budgie Desktop 10.2.8
- Sync some essential patches for an enhanced experience
* Thu Jul 28 2016 ikey.doherty@gmail.com
- Remove the screensaver component for now
* Mon Jul 11 2016 ikey.doherty@gmail.com
- Update to v10.2.6
  - https://github.com/solus-project/budgie-desktop/releases/tag/v10.2.6
* Sun Mar 27 2016 ikey.doherty@gmail.com
- Fix version number in documentation - we didn't update it in this
  point release
* Sun Mar 27 2016 ikey.doherty@gmail.com
- Update to v10.2.5, and exclude .la files
* Sun Feb 28 2016 ikey.doherty@gmail.com
- Account for html files too
* Sun Feb 28 2016 ikey.doherty@gmail.com
- Fix noobish packaging issues
* Sun Feb 28 2016 ikey.doherty@gmail.com
- Add -docs subpackage
* Sun Feb 28 2016 ikey.doherty@gmail.com
- Update to 10.2.4
* Sun Jan  3 2016 ikey.doherty@gmail.com
- Fix many linking/portability issues on other distributions
- Fix nm-applet-likes-small-holes bug (size of x11 tray icons)
- Respect and follow screen resolution changes
- Fix background corruption on resume with NVIDIA gpus
- Fix use of colours for backgrounds
- Replace polkit-gnome dependency with our own new budgie-polkit
- Refactor much of the codebase into smallerl ibraries
- Updated translations
- Fix bug #166 (firefox becomes homeless)
- Fix uhm-is-that-youtube-i-see-through-gedit-thar transparency issue
- Consumed several pizzas
* Wed Dec 30 2015 ikey.doherty@gmail.com
- Use find_lang due to borked directory ownership
* Wed Dec 30 2015 ikey.doherty@gmail.com
- Drop requirements down to GNOME 3.16 stack for openSUSE Leap 42 users
- Introduce many translations
- Fix derpiness of panel when using Raven (moving screen edge)
- Partially fix mumble notifications (more to happen here yet)
- Use unique desktop name (XDG_CURRENT_DESKTOP=Budgie:GNOME)
- Ship our own nm-applet .desktop launcher until we have our own network settings
- Go back to "view-grid-symbolic" icon
* Mon Dec 28 2015 ikey.doherty@gmail.com
- Drop gnome-control-center dependency, causing issues on Fedora
- Apply some patches to enable building on 3.16 GNOME stack (from git)
* Mon Dec 28 2015 ikey.doherty@gmail.com
- Initial packaging for openSUSE:Factory and Fedora 23
